module.exports = {
    root: true,
    ignorePatterns: [
        "projects/**/*",
        "node_modules/**/*"
    ],
    overrides: [
        {
            files: [
                "*.ts"
            ],
            parserOptions: {
                tsconfigRootDir: __dirname,
                project: [
                    "tsconfig.json",
                    "e2e/tsconfig.json"
                ],
                createDefaultProgram: true
            },
            extends: [
                "plugin:@angular-eslint/ng-cli-compat",
                "plugin:@angular-eslint/ng-cli-compat--formatting-add-on",
                "plugin:@angular-eslint/template/process-inline-templates"
            ],
            plugins: [
                "change-detection-strategy",
                "unused-imports",
                "solidify",
            ],
            rules: {
                "solidify/copyright-header": ["error",
                    {
                        "file": "copyright-header.js",
                        "inceptionYear": "2017",
                    }
                ],
                "solidify/readonly-injectables": "error",
                "change-detection-strategy/on-push": "error",
                "@angular-eslint/component-class-suffix": [
                    "error",
                    {
                        "suffixes": [
                            "AppComponent",
                            "Routable",
                            "Presentational",
                            "Container",
                            "Dialog",
                            "Form"
                        ]
                    }
                ],
                "@angular-eslint/component-selector": [
                    "error",
                    {
                        "type": "element",
                        "style": "kebab-case"
                    }
                ],
                "@angular-eslint/directive-class-suffix": "off",
                "@angular-eslint/directive-selector": [
                    "error",
                    {
                        "type": "attribute",
                        "style": "camelCase"
                    }
                ],
                "@angular-eslint/no-input-rename": "off",
                "@angular-eslint/no-output-on-prefix": "off",
                "@angular-eslint/no-output-rename": "off",
                "@typescript-eslint/array-type": [
                    "error",
                    {
                        "default": "array"
                    }
                ],
                "@typescript-eslint/consistent-type-definitions": "error",
                "@typescript-eslint/dot-notation": "off",
                "@typescript-eslint/explicit-member-accessibility": [
                    "off",
                    {
                        "accessibility": "explicit"
                    }
                ],
                "@typescript-eslint/member-delimiter-style": [
                    "error",
                    {
                        "multiline": {
                            "delimiter": "semi",
                            "requireLast": true
                        },
                        "singleline": {
                            "delimiter": "comma",
                            "requireLast": false
                        }
                    }
                ],
                "no-unused-vars": "off",
                "unused-imports/no-unused-imports": "error",
                "@typescript-eslint/member-ordering": "off",
                "@typescript-eslint/naming-convention": [
                    "error",
                    {
                        "selector": "variable",
                        "format": [
                            "camelCase",
                            "UPPER_CASE",
                            "snake_case",
                            "PascalCase"
                        ]
                    },
                    {
                        "selector": ["function", "variable"],
                        "modifiers": ["protected"],
                        "format": ["camelCase"],
                        "leadingUnderscore": "require"
                    },
                    {
                        "selector": ["function", "variable"],
                        "modifiers": ["private"],
                        "format": ["camelCase"],
                        "leadingUnderscore": "require"
                    },
                    {
                        "selector": ["property"],
                        "modifiers": ["protected"],
                        "format": ["camelCase", "UPPER_CASE"],
                        "leadingUnderscore": "require"
                    },
                    {
                        "selector": ["property"],
                        "modifiers": ["private"],
                        "format": ["camelCase", "UPPER_CASE"],
                        "leadingUnderscore": "require"
                    },
                    {
                        "selector": ["variable"],
                        "modifiers": ["private", "readonly"],
                        "format": ["UPPER_CASE", "camelCase"],
                        "leadingUnderscore": "require"
                    },
                    {
                        "selector": ["variable"],
                        "modifiers": ["protected", "readonly"],
                        "format": ["UPPER_CASE", "camelCase"],
                        "leadingUnderscore": "require"
                    },
                ],
                "@typescript-eslint/no-empty-interface": "off",
                "@typescript-eslint/no-namespace": [
                    "off",
                    {
                        "allowDeclarations": true,
                        "allowDefinitionFiles": true
                    }
                ],
                "@typescript-eslint/no-inferrable-types": [
                    "off",
                    {
                        "ignoreParameters": true
                    }
                ],
                "@typescript-eslint/quotes": [
                    "error",
                    "double",
                    {
                        "allowTemplateLiterals": true
                    }
                ],
                "@typescript-eslint/semi": [
                    "error"
                ],
                "@typescript-eslint/no-unused-expressions": [
                    "error"
                ],
                "@typescript-eslint/explicit-function-return-type": [
                    "error",
                    {
                        "allowExpressions": true,
                    }
                ],
                "arrow-body-style": [
                    "error",
                    "as-needed"
                ],
                "brace-style": [
                    "error",
                    "1tbs"
                ],
                "comma-dangle": [
                    "error",
                    {
                        "arrays": "always-multiline",
                        "objects": "always-multiline",
                        "imports": "always-multiline",
                        "exports": "always-multiline",
                        "functions": "always-multiline"
                    }
                ],
                "complexity": [
                    "error",
                    {
                        "max": 200
                    }
                ],
                "import/no-deprecated": "off",
                "jsdoc/no-types": "off",
                "max-len": "off",
                "no-console": [
                    "error",
                    {
                        "allow": [
                            "null"
                        ]
                    }
                ],
                "no-redeclare": "off",
                "no-undef-init": "off",
                "no-underscore-dangle": "off",
                "no-mixed-spaces-and-tabs": [
                    "error"
                ],
                "no-restricted-imports": [
                    "error",
                    {
                        "paths": [],
                        "patterns": [
                            "rxjs/Rx",
                            "@app/generated-api",
                            "**/generated-api"
                        ]
                    }
                ],
                "object-shorthand": "off"
            }
        },
        {
            files: [
                "*.html"
            ],
            extends: [
                "plugin:@angular-eslint/template/recommended"
            ],
            rules: {}
        }
    ]
}
